@@ -6,6 +6,8 @@ from django.utils import timezone
 # Create your models here.
 
 class ExceptionReport(models.Model):
+    """ When a 500 error happen in a django view, a report will be recorded here
+    """
     subject = models.CharField(max_length=256)
     message = models.TextField(null=True, blank=True)
     html_message = models.TextField(null=True, blank=True)
@@ -16,9 +18,12 @@ class ExceptionReport(models.Model):
         ordering = ['-id']
 
     def __str__(self):
+        """ the string method """
         return self.subject
     
     def get_similar(self):
+        """ return other ExceptionReports with the same subject of this one
+        """
         errors = ExceptionReport.objects.exclude(pk=self.pk
                     ).filter(subject__contains=self.subject)
         return errors
